==> hoth-form-0.0.1.tgz: package/lib/test/reducers.spec.js <==
'use strict';

var _chai = require('chai');

var _chai2 = _interopRequireDefault(_chai);

var _chaiSubset = require('chai-subset');

var _chaiSubset2 = _interopRequireDefault(_chaiSubset);

var _immutable = require('immutable');

var _reducers = require('../reducers');

var _reducers2 = _interopRequireDefault(_reducers);

var _config = require('../config');

var _config2 = _interopRequireDefault(_config);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_chai2.default.use(_chaiSubset2.default);

var actionTypes = _config2.default.actionTypes;

var initFields = {
  'username': {
    value: 'john',
    disabled: true
  },
  'password': 'doe',
  'transport': {
    fields: ['feet', 'car', 'bicycle', 'moto', 'turbodesk'],
    value: ['car', 'turbodesk']
  },
  'transport.feet': {
    fields: ['left', 'right', 'both'],
    value: 'right'
  },
  'transport.car': {
    fields: ['toyota', 'mazda', 'ford'],
    value: ['toyota', 'ford']
  },
  'transport.car.color': {
    fields: {
      red: {},
      green: {},
      blue: { disabled: true }
    },
    value: 'red'
  },
  'agree': true
};
var initialized = (0, _immutable.Map)({
  testForm1: (0, _immutable.Map)({
    fields: {}
  }),
  testForm2: (0, _immutable.Map)({
    initialized: true,
    fields: (0, _immutable.Map)({
      'username': {
        initialValue: 'john',
        value: 'john',
        disabled: true
      },
      'password': {
        initialValue: 'doe',
        value: 'doe'
      },
      'transport': {
        fields: {
          feet: { checked: false },
          car: { checked: true },
          bicycle: { checked: false },
          moto: { checked: false },
          turbodesk: { checked: true }
        },
        initialValue: ['car', 'turbodesk'],
        value: ['car', 'turbodesk']
      },
      'transport.feet': {
        fields: {
          left: { checked: false },
          right: { checked: true },
          both: { checked: false }
        },
        initialValue: 'right',
        value: 'right'
      },
      'transport.car': {
        fields: {
          toyota: { checked: true },
          mazda: { checked: false },
          ford: { checked: true }
        },
        initialValue: ['toyota', 'ford'],
        value: ['toyota', 'ford']
      },
      'transport.car.color': {
        fields: {
          red: { checked: true },
          green: { checked: false },
          blue: { disabled: true, checked: false }
        },
        initialValue: 'red',
        value: 'red'
      },
      'agree': {
        initialValue: true,
        value: true,
        checked: true
      },
      'nonFieldErrors': {
        errors: null
      }
    })
  })
});

describe('Form reducer', function () {
  it('has proper initial state', function () {
    var nextState = (0, _reducers2.default)(undefined, { type: 'TEST' });
    (0, _chai.expect)(nextState.toJS()).to.eql({});
  });

  it('handles INIT_FORM action', function () {
    var state = (0, _immutable.Map)({
      testForm1: { fields: {} }
    });
    var action = {
      type: actionTypes.initForm,
      payload: {
        id: 'testForm2',
        fields: initFields
      }
    };
    var nextState = (0, _reducers2.default)(state, action);
    (0, _chai.expect)(nextState.toJS()).to.eql(initialized.toJS());
  });

  it('handles EDIT_FIELDS action', function () {
    var state = initialized;
    var nextState = (0, _reducers2.default)(state, {
      type: actionTypes.editFields,
      payload: {
        id: 'testForm2',
        fields: {
          'username': {
            value: 'mark',
            disabled: false
          },
          'agree': {
            value: false
          },
          'transport': {
            fields: {
              feet: { checked: true }
            }
          },
          'transport.car': {
            value: ['mazda']
          }
        },
        setValue: true
      }
    });
    (0, _chai.expect)(nextState.toJS()).to.eql({
      testForm1: {
        fields: {}
      },
      testForm2: {
        initialized: true,
        fields: {
          'username': {
            initialValue: 'john',
            value: 'mark',
            disabled: false
          },
          'password': {
            initialValue: 'doe',
            value: 'doe'
          },
          'transport': {
            fields: {
              feet: { checked: true },
              car: { checked: true },
              bicycle: { checked: false },
              moto: { checked: false },
              turbodesk: { checked: true }
            },
            initialValue: ['car', 'turbodesk'],
            value: ['feet', 'car', 'turbodesk'] },
          'transport.feet': {
            fields: {
              left: { checked: false },
              right: { checked: true },
              both: { checked: false }
            },
            initialValue: 'right',
            value: 'right'
          },
          'transport.car': {
            fields: {
              toyota: { checked: false },
              mazda: { checked: true },
              ford: { checked: false }
            },
            initialValue: ['toyota', 'ford'],
            value: ['mazda']
          },
          'transport.car.color': {
            fields: {
              red: { checked: true },
              green: { checked: false },
              blue: { disabled: true, checked: false }
            },
            initialValue: 'red',
            value: 'red'
          },
          'agree': {
            initialValue: true,
            value: false,
            checked: false
          },
          'nonFieldErrors': {
            errors: null
          }
        }
      }
    });
  });

  it('handles CHANGE_FOCUS action');

  it('handles SET_ERRORS action', function () {
    var state = initialized.setIn(['testForm2', 'fields', 'password'], { errors: 'Some error' });
    var nextState = (0, _reducers2.default)(state, {
      type: actionTypes.setErrors,
      payload: {
        id: 'testForm2',
        fields: {
          username: 'Too many johnes',
          nonFieldErrors: 'Not so fast'
        }
      }
    });
    (0, _chai.expect)(nextState.toJS()).to.containSubset({
      testForm2: {
        fields: {
          username: { errors: ['Too many johnes'] },
          password: { errors: null },
          nonFieldErrors: { errors: ['Not so fast'] }
        }
      }
    });
  });

  it('handles DESTROY_FORM action', function () {
    var state = initialized;
    var nextState = (0, _reducers2.default)(state, {
      type: actionTypes.destroyForm,
      payload: { id: 'testForm2' }
    });
    (0, _chai.expect)(nextState.toJS()).to.eql({
      'testForm1': {
        fields: {}
      }
    });
  });
});

==> hoth-form-0.0.5.tgz: package/lib/test/reducers.spec.js <==
'use strict';

var _chai = require('chai');

var _chai2 = _interopRequireDefault(_chai);

var _chaiSubset = require('chai-subset');

var _chaiSubset2 = _interopRequireDefault(_chaiSubset);

var _immutable = require('immutable');

var _reducers = require('../reducers');

var _reducers2 = _interopRequireDefault(_reducers);

var _config = require('../config');

var _config2 = _interopRequireDefault(_config);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

_chai2.default.use(_chaiSubset2.default);

var actionTypes = _config2.default.actionTypes;

var initFields = {
  'username': {
    value: 'john',
    disabled: true
  },
  'password': 'doe',
  'transport': {
    fields: ['feet', 'car', 'bicycle', 'moto', 'turbodesk'],
    value: ['car', 'turbodesk']
  },
  'transport.feet': {
    fields: ['left', 'right', 'both'],
    value: 'right'
  },
  'transport.car': {
    fields: ['toyota', 'mazda', 'ford'],
    value: ['toyota', 'ford']
  },
  'transport.car.color': {
    fields: {
      red: {},
      green: {},
      blue: { disabled: true }
    },
    value: 'red'
  },
  'agree': false
};
var initialized = (0, _immutable.Map)({
  testForm1: (0, _immutable.Map)({
    fields: {}
  }),
  testForm2: (0, _immutable.Map)({
    initialized: true,
    fields: (0, _immutable.Map)({
      'username': {
        initialValue: 'john',
        value: 'john',
        disabled: true
      },
      'password': {
        initialValue: 'doe',
        value: 'doe'
      },
      'transport': {
        fields: {
          feet: { checked: false },
          car: { checked: true },
          bicycle: { checked: false },
          moto: { checked: false },
          turbodesk: { checked: true }
        },
        initialValue: ['car', 'turbodesk'],
        value: ['car', 'turbodesk']
      },
      'transport.feet': {
        fields: {
          left: { checked: false },
          right: { checked: true },
          both: { checked: false }
        },
        initialValue: 'right',
        value: 'right'
      },
      'transport.car': {
        fields: {
          toyota: { checked: true },
          mazda: { checked: false },
          ford: { checked: true }
        },
        initialValue: ['toyota', 'ford'],
        value: ['toyota', 'ford']
      },
      'transport.car.color': {
        fields: {
          red: { checked: true },
          green: { checked: false },
          blue: { disabled: true, checked: false }
        },
        initialValue: 'red',
        value: 'red'
      },
      'agree': {
        initialValue: false,
        value: false,
        checked: false
      },
      'nonFieldErrors': {
        errors: null
      }
    })
  })
});

describe('Form reducer', function () {
  it('has proper initial state', function () {
    var nextState = (0, _reducers2.default)(undefined, { type: 'TEST' });
    (0, _chai.expect)(nextState.toJS()).to.eql({});
  });

  it('correctly uses nonFieldErrorsKey value', function () {
    _config2.default.nonFieldErrorsKey = 'formErrors';
    var state = (0, _immutable.Map)();
    var action = {
      type: actionTypes.initForm,
      payload: {
        id: 'testForm2',
        fields: initFields
      }
    };
    var nextState = (0, _reducers2.default)(state, action);
    (0, _chai.expect)(nextState.toJS()).to.containSubset({
      testForm2: {
        fields: { formErrors: { errors: null } }
      }
    });
    _config2.default.nonFieldErrorsKey = 'nonFieldErrors';
  });

  it('handles INIT_FORM action', function () {
    var state = (0, _immutable.Map)({
      testForm1: { fields: {} }
    });
    var action = {
      type: actionTypes.initForm,
      payload: {
        id: 'testForm2',
        fields: initFields
      }
    };
    var nextState = (0, _reducers2.default)(state, action);
    (0, _chai.expect)(nextState.toJS()).to.eql(initialized.toJS());
  });

  it('handles EDIT_FIELDS action', function () {
    var state = initialized;
    var nextState = (0, _reducers2.default)(state, {
      type: actionTypes.editFields,
      payload: {
        id: 'testForm2',
        fields: {
          'username': {
            value: 'mark',
            disabled: false
          },
          'password': {
            value: 'doe'
          },
          'agree': {
            value: true
          },
          'transport': {
            fields: {
              feet: { checked: true }
            }
          },
          'transport.car': {
            value: ['ford', 'toyota']
          }
        },
        setValue: true
      }
    });
    (0, _chai.expect)(nextState.toJS()).to.eql({
      testForm1: {
        fields: {}
      },
      testForm2: {
        initialized: true,
        fields: {
          'username': {
            initialValue: 'john',
            value: 'mark',
            disabled: false,
            dirty: true
          },
          'password': {
            initialValue: 'doe',
            value: 'doe',
            dirty: false
          },
          'transport': {
            fields: {
              feet: { checked: true },
              car: { checked: true },
              bicycle: { checked: false },
              moto: { checked: false },
              turbodesk: { checked: true }
            },
            initialValue: ['car', 'turbodesk'],
            value: ['feet', 'car', 'turbodesk'], // Potential test failure here.
            // Because values are determined by iteratng through fields' keys and thus are not ordered.
            dirty: true
          },
          'transport.feet': {
            fields: {
              left: { checked: false },
              right: { checked: true },
              both: { checked: false }
            },
            initialValue: 'right',
            value: 'right'
          },
          'transport.car': {
            fields: {
              toyota: { checked: true },
              mazda: { checked: false },
              ford: { checked: true }
            },
            initialValue: ['toyota', 'ford'],
            value: ['ford', 'toyota'],
            dirty: false // note different order in initialValue and value
          },
          'transport.car.color': {
            fields: {
              red: { checked: true },
              green: { checked: false },
              blue: { disabled: true, checked: false }
            },
            initialValue: 'red',
            value: 'red'
          },
          'agree': {
            initialValue: false,
            value: true,
            checked: true,
            dirty: true
          },
          'nonFieldErrors': {
            errors: null
          }
        }
      }
    });
  });

  it('handles CHANGE_FOCUS action', function () {
    var state = initialized;
    var nextState = (0, _reducers2.default)(state, {
      type: actionTypes.changeFocus,
      payload: {
        id: 'testForm2',
        fields: {
          username: { active: true }
        }
      }
    });
    (0, _chai.expect)(nextState.toJS()).to.containSubset({
      testForm2: {
        fields: {
          username: { active: true }
        }
      }
    });
  });

  it('handles SET_ERRORS action', function () {
    var state = initialized.setIn(['testForm2', 'fields', 'password'], { errors: 'Some error' });
    var nextState = (0, _reducers2.default)(state, {
      type: actionTypes.setErrors,
      payload: {
        id: 'testForm2',
        fields: {
          username: 'Too many johnes',
          nonFieldErrors: 'Not so fast'
        }
      }
    });
    (0, _chai.expect)(nextState.toJS()).to.containSubset({
      testForm2: {
        fields: {
          username: { errors: ['Too many johnes'] },
          password: { errors: null },
          nonFieldErrors: { errors: ['Not so fast'] }
        }
      }
    });
  });

  it('handles DESTROY_FORM action', function () {
    var state = initialized;
    var nextState = (0, _reducers2.default)(state, {
      type: actionTypes.destroyForm,
      payload: { id: 'testForm2' }
    });
    (0, _chai.expect)(nextState.toJS()).to.eql({
      'testForm1': {
        fields: {}
      }
    });
  });
});
